"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const utils_1 = require("../utils");
exports.localModuleResolver = {
    resolve(moduleName, containingFile, originModuleName = moduleName) {
        if (moduleName.startsWith("file://")) {
            // file protocol is always a unix style path
            // eg: file:///Users/deno/project/mod.ts in MacOS
            // eg: file:///Home/deno/project/mod.ts in Linux
            // eg: file://d:/project/mod.ts in Window
            moduleName = moduleName.replace(/^file:\/\//, "");
        }
        const moduleFilepath = path_1.default.resolve(path_1.default.dirname(containingFile), utils_1.normalizeFilepath(moduleName));
        if (!utils_1.pathExistsSync(moduleFilepath)) {
            return;
        }
        return {
            originModuleName,
            filepath: moduleFilepath,
            extension: getExtensionFromFile(moduleFilepath),
        };
    },
};
function getExtensionFromFile(filename) {
    const extName = path_1.default.extname(filename);
    if (extName === ".ts") {
        if (/\.d\.ts$/.test(filename)) {
            return ".d.ts";
        }
    }
    return extName;
}
exports.getExtensionFromFile = getExtensionFromFile;
//# sourceMappingURL=local_module_resolver.js.map